===============================
emanate
===============================


.. image:: https://img.shields.io/pypi/v/yg.emanate.svg
        :target: https://pypi.python.org/pypi/yg.emanate

.. image:: https://img.shields.io/travis/yougov/yg.emanate.svg
        :target: https://travis-ci.org/yougov/yg.emanate

.. .. image:: https://readthedocs.org/projects/ygemanate/badge/?version=latest
..         :target: https://ygemanate.readthedocs.io/en/latest/?badge=latest
..         :alt: Documentation Status

.. image:: https://pyup.io/repos/github/yougov/yg.emanate/shield.svg
     :target: https://pyup.io/repos/github/yougov/yg.emanate/
     :alt: Updates


Lightweight event system for Python


* Free software: MIT license


Features
--------

* TODO

Credits
---------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage

